.. tekmpesa documentation master file, created by
   sphinx-quickstart on Sat, Nov 28 08:31:41 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Tekmpesa - tekmpesa's documentation!
========================================
Tekmpesa is an open-source Python SDK supporting 5 Countries for the MPESA mobile money platform.
It was designed to provide a simple, clear, and concise interface to quickly
integrate MPESA payments into python applications.


Features
----------
- Simple, Clean, and Consistent API
- Supports MPESA Across 5 Countries in Africa.

* :mod:`mpesa.kenya`

* :mod:`mpesa.ghana`

* :mod:`mpesa.tanzania`

* :mod:`mpesa.mozambique`

* :mod:`mpesa.drc`


.. csv-table:: Supported Countries.
   :header: "Country","Supported"
   :widths: 30,10

    "Kenya","YES"
    "Tanzania","YES"
    "Ghana","YES"
    "Democratic Republic of Congo (DRC)","YES"
    "Mozambique","YES"
    "Egypt","NO"
    "Lesotho","NO"

.. toctree::
   :maxdepth: 3
   :caption: Table Of Contents:

   Overview <contents.rst>
   API Reference <api.rst>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
